==> opensearch-dashboards-2.11.1.tgz: opensearch-dashboards/src/core/test_helpers/strip_ansi_snapshot_serializer.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.stripAnsiSnapshotSerializer = void 0;

var _hasAnsi = _interopRequireDefault(require("has-ansi"));

var _stripAnsi = _interopRequireDefault(require("strip-ansi"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const stripAnsiSnapshotSerializer = {
  serialize(value) {
    return (0, _stripAnsi.default)(value);
  },

  test(value) {
    return typeof value === 'string' && (0, _hasAnsi.default)(value);
  }

};
exports.stripAnsiSnapshotSerializer = stripAnsiSnapshotSerializer;

==> opensearch-dashboards-2.16.0.tgz: opensearch-dashboards/src/core/test_helpers/strip_ansi_snapshot_serializer.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.stripAnsiSnapshotSerializer = void 0;
var _hasAnsi = _interopRequireDefault(require("has-ansi"));
var _stripAnsi = _interopRequireDefault(require("strip-ansi"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

const stripAnsiSnapshotSerializer = exports.stripAnsiSnapshotSerializer = {
  serialize(value) {
    return (0, _stripAnsi.default)(value);
  },
  test(value) {
    return typeof value === 'string' && (0, _hasAnsi.default)(value);
  }
};
